@@ -11,17 +11,11 @@ import sys
 import setuptools
 
 from setupmeta import current_folder, get_words, listify, MetaDefs, PKGID, project_path, readlines, relative_path
-from setupmeta import Requirements, requirements_from_file, short, trace, warn
+from setupmeta import Requirements, requirements_from_file, RequirementsFile, short, trace, warn
 from setupmeta.content import find_contents, load_contents, load_readme, resolved_paths
 from setupmeta.license import determined_license
 from setupmeta.versioning import project_scm, Versioning
 
-try:
-    basestring
-
-except NameError:
-    basestring = str
-
 
 # Used to mark which key/values were provided explicitly in setup.py
 EXPLICIT = "explicit"
@@ -291,8 +285,8 @@ def get_pip():  # pragma: no cover, see https://github.com/pypa/setuptools/issue
     """
     try:
         # pip >= 19.3
-        from pip._internal.req import parse_requirements
-        from pip._internal.network.session import PipSession
+        from pip._internal.req import parse_requirements  # noqa
+        from pip._internal.network.session import PipSession  # noqa
 
         return parse_requirements, PipSession
 
@@ -301,8 +295,8 @@ def get_pip():  # pragma: no cover, see https://github.com/pypa/setuptools/issue
 
     try:
         # pip >= 10.0
-        from pip._internal.req import parse_requirements
-        from pip._internal.download import PipSession
+        from pip._internal.req import parse_requirements  # noqa
+        from pip._internal.download import PipSession  # noqa
 
         return parse_requirements, PipSession
 
@@ -347,9 +341,9 @@ class PackageInfo:
         self.path = os.path.join(root, "PKG-INFO")
         self.info = {}
         self.name = None
-        self.dependency_links = None
         self.entry_points_txt = None
         self.requires_txt = None
+        self.requires_dist = None
         lines = readlines(self.path)
         if not lines:
             return
@@ -361,10 +355,18 @@ class PackageInfo:
             if m:
                 key = m.group(1).lower().replace("-", "_")
                 key = self._canonical_names.get(key, key)
+                value = m.group(2)
+                if key == "requires_dist":
+                    # This code tries to support PEP-517, until setuptools retired
+                    if self.requires_dist is None:
+                        self.requires_dist = []
+
+                    self.requires_dist.append(value)
+                    continue
+
                 if key not in MetaDefs.all_fields:
                     continue
 
-                value = m.group(2)
                 if key in self._list_types:
                     if key not in self.info:
                         self.info[key] = []
@@ -386,6 +388,18 @@ class PackageInfo:
         self.info["long_description"] = "\n".join(self.info.get("long_description", []))
         self.load_more_info(root)
 
+    def get_requirements(self):
+        """
+        Returns:
+            (RequirementsFile): Requirements extracted from PKG-INFO
+        """
+        if self.requires_dist:
+            return RequirementsFile.from_lines(self.requires_dist, do_abstract=False, source_path="PKG-INFO/Requires-Dist")
+
+        if self.requires_txt:
+            # requires.txt is not produced anymore by setuptools 68.2+
+            return RequirementsFile.from_file(self.requires_txt, do_abstract=False)
+
     def load_more_info(self, folder, depth=3):
         """
         :param str folder: Folder to scan for .egg-info file
@@ -397,7 +411,6 @@ class PackageInfo:
 
         path = os.path.join(folder, "%s.egg-info" % self.pythonified_name)
         if os.path.isdir(path):
-            self.dependency_links = self.checked_file(path, "dependency_links.txt")
             self.entry_points_txt = self.checked_file(path, "entry_points.txt")
             self.requires_txt = self.checked_file(path, "requires.txt")
             return True
@@ -406,13 +419,17 @@ class PackageInfo:
             if self.load_more_info(os.path.join(folder, fname), depth=depth - 1):
                 return True
 
-    def checked_file(self, folder, filename):
+    @staticmethod
+    def checked_file(folder, basename):
         """
-        :param str folder: Folder
-        :param str filename: Basename
-        :return str|None: Full path to file, if it exists
+        Args:
+            folder (str): Folder
+            basename (str): Basename
+
+        Returns:
+            (str | None): Full path, if it exists
         """
-        path = os.path.join(folder, filename)
+        path = os.path.join(folder, basename)
         if os.path.exists(path):
             return path
 
@@ -420,27 +437,28 @@ class PackageInfo:
 class SetupMeta(Settings):
     """ Find usable definitions throughout a project SetupPy SetupMeta """
 
+    pkg_info = None  # type: PackageInfo
+    requirements = None  # type: Requirements
+    versioning = None  # type: Versioning
+
     def __init__(self):
-        """
-        :param upstream: Either a dict or Distribution
-        """
         Settings.__init__(self)
         self.attrs = {}
 
     def preprocess(self, upstream):
         self.find_project_dir(MetaDefs.dist_to_dict(upstream).pop("_setup_py_path", None))
 
-        for require_field in ("install_requires", "tests_require"):
+        for require_field in ("install_requires",):
             value = getattr(upstream, require_field)
-            if isinstance(value, basestring) and value.startswith("@"):
+            if isinstance(value, str) and value.startswith("@"):
                 self.add_definition(require_field, value, EXPLICIT)
                 self.add_definition(require_field, requirements_from_file(value[1:]) or [], source=value[1:], override=True)
 
         if isinstance(upstream.extras_require, dict):
-            if any([isinstance(deps, basestring) and deps.startswith("@") for deps in upstream.extras_require.values()]):
+            if any([isinstance(deps, str) and deps.startswith("@") for deps in upstream.extras_require.values()]):
                 self.add_definition("extras_require", upstream.extras_require, EXPLICIT)
                 self.add_definition("extras_require", {
-                        extra: (requirements_from_file(deps[1:]) or []) if isinstance(deps, basestring) and deps.startswith("@") else deps
+                        extra: (requirements_from_file(deps[1:]) or []) if isinstance(deps, str) and deps.startswith("@") else deps
                         for extra, deps in upstream.extras_require.items()
                     }, "preprocessed", override=True)
 
@@ -463,14 +481,14 @@ class SetupMeta(Settings):
             if key in MetaDefs.all_fields:
                 self.add_definition(key, value, relative_path(self.pkg_info.path))
 
-        # Allow to auto-fill 'name' from setup.py's __title__, if any
+        # Allow to autofill 'name' from setup.py __title__, if any
         self.merge(SimpleModule("setup.py"))
         title = self.definitions.get("title")
         if title:
             self.auto_fill("name", title.value, source=title.source)
 
         if "--name" in sys.argv[1:3]:
-            # No need to waste time auto-filling anything if all we need to show is package name
+            # No need to waste time filling anything if all we need to show is package name
             return self
 
         packages = self.attrs.get("packages", [])
@@ -535,6 +553,9 @@ class SetupMeta(Settings):
 
         scm = scm or project_scm(MetaDefs.project_dir)
         self.versioning = Versioning(self, scm)
+        if scm and self.versioning.strategy and self.versioning.strategy.version_tag:
+            scm.version_tag = self.versioning.strategy.version_tag
+
         self.versioning.auto_fill_version()
 
         self.fill_urls()
@@ -545,10 +566,6 @@ class SetupMeta(Settings):
 
         self.requirements = Requirements(self.pkg_info)
         self.auto_fill_requires("install_requires")
-        self.auto_fill_requires("tests_require")
-        if self.requirements.dependency_links:
-            self.auto_fill("dependency_links", self.requirements.dependency_links, self.requirements.links_source)
-
         self.auto_fill_entry_points()
         self.auto_fill_license()
         self.auto_fill_long_description()
@@ -558,8 +575,12 @@ class SetupMeta(Settings):
 
     def resolved_url(self, url, base=None):
         """
-        :param str|None url: Url to resolve
-        :return str|None: Resolve {name} and {version} markers in given url
+        Args:
+            url (str | None): Url to resolve
+            base (str | None): Base url to use
+
+        Returns:
+            (str): Resolved url, with {name} and {version} markers filled
         """
         if base and url and "://" not in url:
             # Convenience: auto-complete relative urls
@@ -568,7 +589,7 @@ class SetupMeta(Settings):
         return url and url.format(name=self.name, version=self.version)
 
     def fill_urls(self):
-        """ Auto-fill url and download_url """
+        """Autofill 'url' and 'download_url'"""
         url = self.value("url")
         download_url = self.value("download_url")
         bugtrack_url = self.value("bugtrack_url")
@@ -587,12 +608,14 @@ class SetupMeta(Settings):
         self.auto_fill("download_url", self.resolved_url(download_url, base=url))
         self.auto_fill("bugtrack_url", self.resolved_url(bugtrack_url, base=url))
 
-    def find_project_dir(self, setup_py_path):
+    @staticmethod
+    def find_project_dir(setup_py_path):
         """
-        :param str|None setup_py_path: Given setup.py (when invoked from test)
+        Args:
+            setup_py_path (str | None): Given setup.py (when invoked from test)
         """
         if not setup_py_path:
-            # Determine path to setup.py module from call stack
+            # Determine path to 'setup.py' module from call stack
             for frame in inspect.stack():
                 module = inspect.getmodule(frame[0])
                 if module and is_setup_py_path(module.__file__):
@@ -627,7 +650,7 @@ class SetupMeta(Settings):
                 return description
 
     def auto_fill_long_description(self):
-        """ Auto-fille descriptions from README file """
+        """Autofill descriptions from README file"""
         docstring_lead = self.definitions.pop("docstring_lead", None)
         if docstring_lead and not self.value("description"):
             self.auto_fill("description", docstring_lead.value, source=docstring_lead.source)
@@ -656,12 +679,12 @@ class SetupMeta(Settings):
         path = "%s.ini" % key
         self.add_definition(key, load_contents(path), path)
 
-    def auto_fill_license(self, key="license"):
-        """ Try to auto-determine the license """
+    def auto_fill_license(self):
+        """Try to auto-determine the license"""
         contents, _ = find_contents(["LICENSE*"], limit=20)
-        short = determined_license(contents)
-        if short:
-            self.auto_fill("license", short)
+        contents = determined_license(contents)
+        if contents:
+            self.auto_fill("license", contents)
 
     def auto_fill_requires(self, field):
         req = getattr(self.requirements, field)
@@ -681,14 +704,14 @@ class SetupMeta(Settings):
         return self.value("version")
 
     def auto_fill_include_package_data(self):
-        """Auto-fill 'include_package_data' if a MANIFEST.in file exists in project"""
+        """Autofill 'include_package_data' if a MANIFEST.in file exists in project"""
         if "include_package_data" not in self.attrs:
             manifest = os.path.join(MetaDefs.project_dir, "MANIFEST.in")
             if os.path.isfile(manifest):
                 self.add_definition("include_package_data", True, os.path.basename(manifest))
 
     def auto_fill(self, field, value, source="auto-fill", override=False):
-        """ Auto-fill 'field' with 'value' """
+        """Autofill 'field' with 'value'"""
         if value and (override or value != self.value(field)):
             override = override or field not in self.attrs
             self.add_definition(field, value, source, override=override)
